@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2015-09-18'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-09-27'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,7 @@ our %_seen_refaddrs;
 our %_subscripts;
 our @_fixups;
 
-our $OPT_PERL_VERSION;
+our $OPT_PERL_VERSION = "5.010";
 
 # BEGIN COPY PASTE FROM Data::Dump
 my %esc = (
@@ -110,7 +110,16 @@ sub _dump {
     } elsif ($ref eq 'REF') {
         $res = "\\"._dump($$val, $subscript);
     } elsif ($ref eq 'CODE') {
-        $res = "sub{'DUMMY'}";
+        require Data::Dumper;
+        local $Data::Dumper::Terse = 1;
+        local $Data::Dumper::Indent = 0;
+        local $Data::Dumper::Deparse = 1;
+        $res = Data::Dumper::Dumper($val);
+        if ($OPT_PERL_VERSION < 5.016) {
+            # older perls' feature.pm doesn't yet support q{no feature ':all';}
+            # so we replace it with q{no feature}.
+            $res =~ s/no feature ':all';/no feature;/m;
+        }
     } else {
         die "Sorry, I can't dump $val (ref=$ref) yet";
     }
@@ -161,7 +170,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.12 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-09-18.
+This document describes version 0.13 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-09-27.
 
 =head1 SYNOPSIS
 
@@ -171,17 +180,13 @@ This document describes version 0.12 of Data::Dmp (from Perl distribution Data-D
 
 =head1 DESCRIPTION
 
-Data::Dmp is a Perl dumper like L<Data::Dumper>. It's compact (only about 120
+Data::Dmp is a Perl dumper like L<Data::Dumper>. It's compact (only about 150
 lines of code long), starts fast and does not use other module except
 L<Regexp::Stringify> when dumping regexes. It produces compact output (similar
 to L<Data::Dumper::Concise>). It roughly has the same speed as Data::Dumper
 (usually a bit faster for smaller structures), but does not offer the various
-formatting options. It supports dumping objects, regexes, circular structures.
-Its code is based on L<Data::Dump>.
-
-It currently does not support "deparse" like Data::Dumper and dumps coderefs as
-C<< sub{'DUMMY'} >>. Unlike Data::Dump, it currently does not support
-identifying tied data or globs.
+formatting options. It supports dumping objects, regexes, circular structures,
+coderefs. Its code is based on L<Data::Dump>.
 
 =head1 FUNCTIONS
 
@@ -199,31 +204,46 @@ Exported by default. Return dump result as string. Unlike C<Data::Dump>'s C<dd>
 
 =head1 SETTINGS
 
-=head2 $Data::Dmp::OPT_PERL_VERSION => str
+=head2 $Data::Dmp::OPT_PERL_VERSION => str (default: 5.010)
 
-Set target Perl version. Currently this is used when passing to
-L<Regexp::Stringify>. If you set this to, say C<5.010>, then the dumped code
-will keep compatibility with Perl 5.10.0.
+Set target Perl version. If you set this to, say C<5.010>, then the dumped code
+will keep compatibility with Perl 5.10.0. This is used in the following ways:
+
+=over
+
+=item * passed to L<Regexp::Stringify>
+
+=item * when dumping code references
+
+For example, in perls earlier than 5.016, feature.pm does not understand:
+
+ no feature ':all';
+
+so we replace it with:
+
+ no feature;
+
+=back
 
 =head1 BENCHMARKS
 
  [1..10]:
-                     Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump   13874+-21/s            --       -72.1%    -78.3%
- Data::Dumper 49689+-49/s 258.15+-0.64%           --    -22.3%
- Data::Dmp    63974+-80/s 361.12+-0.89% 28.75+-0.21%        --
+                       Rate    Data::Dump Data::Dumper Data::Dmp
+ Data::Dump     28529+-40/s            --       -68.6%    -77.6%
+ Data::Dumper  90760+-110/s 218.13+-0.59%           --    -28.6%
+ Data::Dmp    127150+-220/s 345.69+-0.98%  40.1+-0.29%        --
  
  [1..100]:
-                       Rate  Data::Dump    Data::Dmp Data::Dumper
- Data::Dump   1718.1+-2.2/s          --       -80.4%       -83.3%
- Data::Dmp       8781+-14/s 411.1+-1.1%           --       -14.6%
- Data::Dumper   10284+-82/s 498.6+-4.8% 17.11+-0.95%           --
+                       Rate  Data::Dump Data::Dumper Data::Dmp
+ Data::Dump   3294.3+-6.9/s          --       -77.6%    -78.6%
+ Data::Dumper   14717+-75/s 346.8+-2.5%           --     -4.6%
+ Data::Dmp      15423+-25/s 368.2+-1.3%   4.8+-0.56%        --
  
  Some mixed structure:
-                       Rate    Data::Dump   Data::Dmp Data::Dumper
- Data::Dump   4649.2+-5.8/s            --      -70.1%       -81.3%
- Data::Dmp      15540+-77/s   234.2+-1.7%          --       -37.6%
- Data::Dumper   24911+-33/s 435.81+-0.97% 60.3+-0.82%           --
+                     Rate Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    8119+-18/s         --       -73.7%       -81.5%
+ Data::Dmp    30925+-46/s 280.91+-1%           --       -29.6%
+ Data::Dumper 43921+-13/s  441+-1.2% 42.02+-0.21%           --
 
 =head1 FAQ
 
